@@ -24,9 +24,12 @@ const GLib = imports.gi.GLib;
 
 const MainWindow = imports.mainWindow;
 const Preferences = imports.preferences;
+const SIGINT = 2;
+const SIGTERM = 15;
 
 let application = null;
 
+
 const Application = new Lang.Class({
     Name: 'Application',
     Extends: Gtk.Application,
@@ -91,12 +94,18 @@ const Application = new Lang.Class({
     },
     
     onWindowDestroy: function() {
-        if (MainWindow.wave != null)
-            MainWindow.wave.pipeline.set_state(Gst.State.NULL);          
+        if (MainWindow.wave.pipeline)
+            MainWindow.wave.pipeline.set_state(Gst.State.NULL);
+            
+        if (MainWindow._record.pipeline) 
+            MainWindow._record.pipeline.set_state(Gst.State.NULL);
+        
+        if (MainWindow.play.play) 
+            MainWindow.play.play.set_state(Gst.State.NULL);        
     },
     
     _showPreferences: function() {
-         let preferencesDialog = new Preferences.Preferences();
+        let preferencesDialog = new Preferences.Preferences();
 
         preferencesDialog.widget.connect('response', Lang.bind(this,
             function(widget, response) {
@@ -117,7 +126,7 @@ const Application = new Lang.Class({
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
         aboutDialog.logo_icon_name = 'audio-input-microphone';
-        aboutDialog.version = '3.11.5';
+        aboutDialog.version = '3.11.9';
         aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
         aboutDialog.wrap_license = true;
         aboutDialog.modal = true;
