@@ -24,6 +24,7 @@ const Gdk = imports.gi.Gdk;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const Gst = imports.gi.Gst;
+const Pango = imports.gi.Pango;
 
 const AudioProfile = imports.audioProfile;
 const FileUtil = imports.fileUtil;
@@ -91,7 +92,7 @@ const MainWindow = new Lang.Class({
         params = Params.fill(params, { title: GLib.get_application_name(),
                                        hexpand: true,
                                        vexpand: true, 
-                                       default_width: 675,
+                                       default_width: 800,
                                        default_height: 480 });
         this.parent(params);
 
@@ -117,8 +118,7 @@ const MainView = new Lang.Class({
     Extends: Gtk.Stack,
 
     _init: function(params) {
-        params = Params.fill(params, { hexpand: true,
-                                       vexpand: true,
+        params = Params.fill(params, { vexpand: true,
                                        transition_type: Gtk.StackTransitionType.CROSSFADE,
                                        transition_duration: 100,
                                        visible: true });
@@ -137,7 +137,7 @@ const MainView = new Lang.Class({
         this._scrolledWin.add(this.emptyGrid);
 
         let emptyPageImage = new Gtk.Image({ icon_name: 'audio-input-microphone-symbolic',
-                                             icon_size: Gtk.IconSize.LARGE_TOOLBAR });
+                                             icon_size: Gtk.IconSize.DIALOG });
         emptyPageImage.get_style_context().add_class('dim-label');
         this.emptyGrid.add(emptyPageImage);
         let emptyPageTitle = new Gtk.Label({ label: _("Add Recordings"),
@@ -163,8 +163,7 @@ const MainView = new Lang.Class({
 
         groupGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                    hexpand: true,
-                                   vexpand: true,
-                                   column_homogeneous: true });
+                                   vexpand: true });
         this.add_titled(groupGrid, name, "View");
     },
     
@@ -193,7 +192,9 @@ const MainView = new Lang.Class({
         this._record.stopRecording();
         this.recordGrid.hide();
         recordPipeline = RecordPipelineStates.STOPPED;
-        recordButton.set_sensitive(true);  
+        recordButton.set_sensitive(true);
+        if (this.listBox != null)
+            this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);  
     },
      
     _formatTime: function(unformattedTime) {
@@ -242,12 +243,10 @@ const MainView = new Lang.Class({
         volumeValue.push({ record: 0.5, play: 0.5 });
         activeProfile = AudioProfile.comboBoxMap.OGG_VORBIS;
                 
-        this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+        this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                          height_request: 36,
-                                         width_request: 400,
-                                         hexpand: true,
+                                         width_request: 775,
                                          name: "recordGrid" });
-        this.recordGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
         this.groupGrid.add(this.recordGrid);
         
         this.widgetRecord = new Gtk.Toolbar({ show_arrow: false,
@@ -295,7 +294,7 @@ const MainView = new Lang.Class({
      
     scrolledWinAdd: function() {    
         this._scrolledWin = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN,
-                                                     hexpand: true,
+                                                     width_request: 775,
                                                      vexpand: true });
         this._scrolledWin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this._scrolledWin.get_style_context().add_class('view');
@@ -324,8 +323,7 @@ const MainView = new Lang.Class({
             this._scrolledWin.get_style_context().add_class('emptyGrid');
             this._addEmptyPage();
         } else {       
-            this.listBox = Gtk.ListBox.new({ hexpand: true,
-                                             vexpand: true });
+            this.listBox = Gtk.ListBox.new({ vexpand: true });
             this._scrolledWin.add(this.listBox);
             this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
             this.listBox.set_header_func(null);
@@ -342,10 +340,8 @@ const MainView = new Lang.Class({
             for (let i = this._startIdx; i <= this._endIdx; i++) {
                 this.rowGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                               height_request: 45,
-                                              width_request: 675,
-                                              hexpand: true,
+                                              width_request: 775,
                                               vexpand: true,
-                                              column_homogeneous: true,
                                               name: i.toString() });
                 this.rowGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
                 this.listBox.add(this.rowGrid);
@@ -393,9 +389,9 @@ const MainView = new Lang.Class({
                 this._fileName = new Gtk.Label({ use_markup: true,
                                                  halign: Gtk.Align.START,
                                                  valign: Gtk.Align.START,
-                                                 ellipsize: true,
+                                                 ellipsize: rtl ? Pango.EllipsizeMode.START : Pango.EllipsizeMode.END,
                                                  xalign: 0,
-                                                 width_chars: 40,
+                                                 width_chars: 35,
                                                  margin_top: 5,
                                                  margin_left: rtl ? 0 : 15,
                                                  margin_right: rtl ? 15 : 0,
@@ -410,8 +406,7 @@ const MainView = new Lang.Class({
                                                    name: "PlayLabelBox",
                                                    height_request: 45 });
                 this.rowGrid.attach(this._playLabelBox, 1, 1, 10, 1);
-                this._playLabelBox.show();
-                        
+                this._playLabelBox.show();       
                 this.playDurationLabel = new Gtk.Label({ margin_left: rtl ? 0 : 15,
                                                          margin_right: rtl ? 15 : 0,
                                                          halign: Gtk.Align.END,
@@ -441,13 +436,13 @@ const MainView = new Lang.Class({
                 
                 this.waveFormGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                                    height_request: 45,
-                                                   width_request: 380,
+                                                   width_request: 350,
                                                    valign: Gtk.Align.FILL,
                                                    hexpand: true,
                                                    vexpand: true,
                                                    name: "WaveFormGrid" });
                 this.waveFormGrid.set_no_show_all(true);
-                this.rowGrid.attach(this.waveFormGrid, 11, 1, 18, 4);
+                this.rowGrid.attach(this.waveFormGrid, 11, 1, 18, 2);
                 this.waveFormGrid.show();
                 
                 // info button
@@ -542,6 +537,20 @@ const MainView = new Lang.Class({
                     
                     if (!alwaysShow)
                         child.hide();
+                        
+                    if (child.name == "PlayLabelBox") {
+                        child.show();
+                        child.foreach(Lang.bind(this, 
+                            function(grandchild) {
+                                
+                                if (grandchild.name == "PlayTimeLabel") {
+                                    grandchild.hide();
+                                }
+                                    
+                                if (grandchild.name == "DividerLabel" )
+                                    grandchild.hide();
+                             }));
+                    }
                 }));
                 this.activeState = play.getPipeStates();
                 
@@ -694,6 +703,7 @@ const MainView = new Lang.Class({
                     }
                 }));
             listRow.set_property("width-request", width);
+            log(this.get_allocated_width());
             
             if (this.activeState != PipelineStates.PAUSED) {
                 wave = new Waveform.WaveForm(this.wFGrid, selFile);
