@@ -38,8 +38,6 @@ const INTERVAL = 100000000;
 const peaks = [];
 const pauseVal = 10;
 const waveSamples = 40;
-const SIGINT = 2;
-const SIGTERM = 15;
 
 const WaveType = {
     RECORD: 0,
@@ -68,7 +66,7 @@ const WaveForm = new Lang.Class({
         let drawingWidth = 0;
         let drawingHeight = 0;
         this.drawing = Gtk.DrawingArea.new({ height_request: 45,
-                                             width_request: 380,
+                                             width_request: 325,
                                              valign: Gtk.Align.FILL });
         if (this.waveType == WaveType.RECORD) {
             gridWidth = MainWindow.groupGrid.get_allocated_width();
@@ -76,7 +74,7 @@ const WaveForm = new Lang.Class({
             this.drawing.set_size_request(drawingWidth, 36);
             this._grid.attach(this.drawing, 2, 0, 3, 2);
         } else {
-            this.drawing.set_size_request(380, 36);
+            this.drawing.set_size_request(325, 36);
             this._grid.add(this.drawing);
         }
 
@@ -97,8 +95,8 @@ const WaveForm = new Lang.Class({
         let decode = this.pipeline.get_by_name("decode");
         let bus = this.pipeline.get_bus();
         bus.add_signal_watch();
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, SIGINT, Application.application.onWindowDestroy, this.pipeline);
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, SIGTERM, Application.application.onWindowDestroy, this.pipeline);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy, this.pipeline);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy, this.pipeline);
 
         this.nSamples = Math.ceil(this.duration / INTERVAL);
 
@@ -255,7 +253,7 @@ const WaveForm = new Lang.Class({
     },
     
     endDrawing: function() {
-        let width = this._grid.get_allocated_width();
+        let width = 380;
         
         if(this.pipeline)
             this.stopGeneration();
@@ -263,9 +261,5 @@ const WaveForm = new Lang.Class({
         this.count = 0;
         peaks.length = 0;
         this.drawing.destroy();
-    },
-    
-    print: function() {
-    log("HELL");
     }
 });
